# Generated by Django 5.2.11 on 2026-03-14 02:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_qareports", "0022_historicalnote"),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name="note",
            name="edc_qareports_note_report_model_subj_uniq",
        ),
        migrations.AddField(
            model_name="historicalnote",
            name="visit_code",
            field=models.CharField(blank=True, default="", max_length=25),
        ),
        migrations.AddField(
            model_name="historicalnote",
            name="visit_code_sequence",
            field=models.IntegerField(blank=True, default=0, verbose_name="Sequence"),
        ),
        migrations.AddField(
            model_name="note",
            name="visit_code",
            field=models.CharField(blank=True, default="", max_length=25),
        ),
        migrations.AddField(
            model_name="note",
            name="visit_code_sequence",
            field=models.IntegerField(blank=True, default=0, verbose_name="Sequence"),
        ),
        migrations.AlterField(
            model_name="historicalnote",
            name="status",
            field=models.CharField(
                choices=[
                    ("PENDING", "Data is pending"),
                    ("not_available", "Data not available"),
                    ("closed", "Closed - Final"),
                ],
                default="",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="note",
            name="status",
            field=models.CharField(
                choices=[
                    ("PENDING", "Data is pending"),
                    ("not_available", "Data not available"),
                    ("closed", "Closed - Final"),
                ],
                default="",
                max_length=25,
            ),
        ),
        migrations.AddConstraint(
            model_name="note",
            constraint=models.UniqueConstraint(
                fields=(
                    "report_model",
                    "subject_identifier",
                    "visit_code",
                    "visit_code_sequence",
                ),
                name="edc_qareports_note_report_model_subj_uniq",
            ),
        ),
    ]
