# Generated by Django 5.2.11 on 2026-03-13 23:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0135_alter_stock_allocation"),
    ]

    operations = [
        migrations.AddField(
            model_name="stockavailability",
            name="visit_code_sequence",
            field=models.IntegerField(null=True),
        ),
    ]
