# Generated by Django 4.0.5 on 2022-07-02 15:49

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_pharmacy", "0005_alter_rx_managers"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalrxrefill",
            name="roundup_divisible_by",
            field=models.IntegerField(default=1),
        ),
        migrations.AddField(
            model_name="rxrefill",
            name="roundup_divisible_by",
            field=models.IntegerField(default=1),
        ),
    ]
