from clinicedc_constants import CLOSED, DATA_ISSUE, NOT_AVAILABLE, PENDING

NOTE_STATUSES = (
    (PENDING, "Data is pending"),
    (NOT_AVAILABLE, "Data not available"),
    (DATA_ISSUE, "Data issue"),
    (CLOSED, "Closed - Final"),
)
