# Generated by Django 5.2.11 on 2026-03-17 01:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_qareports",
            "0023_remove_note_edc_qareports_note_report_model_subj_uniq_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalnote",
            name="status",
            field=models.CharField(
                choices=[
                    ("PENDING", "Data is pending"),
                    ("not_available", "Data not available"),
                    ("DATA_ISSUE", "Data issue"),
                    ("closed", "Closed - Final"),
                ],
                default="",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="note",
            name="status",
            field=models.CharField(
                choices=[
                    ("PENDING", "Data is pending"),
                    ("not_available", "Data not available"),
                    ("DATA_ISSUE", "Data issue"),
                    ("closed", "Closed - Final"),
                ],
                default="",
                max_length=25,
            ),
        ),
    ]
