# Generated by Django 5.2.11 on 2026-03-05 18:39

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0134_alter_storagebinproxy_options"),
    ]

    operations = [
        migrations.AlterField(
            model_name="stock",
            name="allocation",
            field=models.OneToOneField(
                blank=True,
                help_text="Subject allocation",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="edc_pharmacy.allocation",
            ),
        ),
    ]
